summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/beam.cc
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-09-23 21:50:33 -0500
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-09-23 21:50:33 -0500
commitb0ed14492f4344a3c3247fdc206fad74a2973bfe (patch)
tree6521cddd673638b367a3f5f3677c12fca9686bfc /crawl-ref/source/beam.cc
parentb8e97166ca3207b75e437f852679c8c4b8e75b6c (diff)
downloadcrawl-ref-b0ed14492f4344a3c3247fdc206fad74a2973bfe.tar.gz
crawl-ref-b0ed14492f4344a3c3247fdc206fad74a2973bfe.zip
Add spelling fixes.
Diffstat (limited to 'crawl-ref/source/beam.cc')
-rw-r--r--crawl-ref/source/beam.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/crawl-ref/source/beam.cc b/crawl-ref/source/beam.cc
index 855060f95c..c22ba8ad09 100644
--- a/crawl-ref/source/beam.cc
+++ b/crawl-ref/source/beam.cc
@@ -199,7 +199,7 @@ bool zapping(zap_type ztype, int power, bolt &pbolt,
pbolt.thrower = KILL_YOU_MISSILE;
// Check whether tracer goes through friendlies.
- // NOTE: Whenever zapping() is called with a randomized value for power
+ // NOTE: Whenever zapping() is called with a randomised value for power
// (or effect), player_tracer should be called directly with the highest
// power possible respecting current skill, experience level, etc.
if (needs_tracer && !player_tracer(ztype, power, pbolt))
@@ -1450,7 +1450,7 @@ bool bolt::invisible() const
return (type == 0 || is_enchantment());
}
-void bolt::initialize_fire()
+void bolt::initialise_fire()
{
// Fix some things which the tracer might have set.
range_used = 0;
@@ -2015,7 +2015,7 @@ void bolt::fire()
void bolt::do_fire()
{
- initialize_fire();
+ initialise_fire();
if (range <= range_used && range > 0)
{
@@ -2133,7 +2133,7 @@ void bolt::do_fire()
// enchantment is yours (and it wasn't a chaos beam, since with chaos
// enchantments are entirely random, and if it randomly attempts
// something which ends up having no obvious effect then the player
- // isn't going to realize it).
+ // isn't going to realise it).
if (!msg_generated && !obvious_effect && is_enchantment()
&& real_flavour != BEAM_CHAOS && YOU_KILL(thrower))
{
@@ -4613,7 +4613,7 @@ void bolt::affect_monster(monsters* mon)
// Player beams which hit friendlies or good neutrals will annoy
// them and be considered naughty if they do damage (this is so as
- // not to penalize players that fling fireballs into a melee with
+ // not to penalise players that fling fireballs into a melee with
// fire elementals on their side - the elementals won't give a sh*t,
// after all).
@@ -5759,7 +5759,7 @@ bool bolt::nice_to(const monsters *mon) const
// A constructor for bolt to help guarantee that we start clean (this has
// caused way too many bugs). Putting it here since there's no good place to
// put it, and it doesn't do anything other than initialize its members.
//
// TODO: Eventually it'd be nice to have a proper factory for these things
// (extended from setup_mons_cast() and zapping() which act as limited ones).
@@ -5759,7 +5759,7 @@ bool bolt::nice_to(const monsters *mon) const
// A constructor for bolt to help guarantee that we start clean (this has
// caused way too many bugs). Putting it here since there's no good place to
-// put it, and it doesn't do anything other than initialize its members.
+// put it, and it doesn't do anything other than initialise its members.
//
// TODO: Eventually it'd be nice to have a proper factory for these things